/***********************************************************************
ColorSafe 1.0 Beta - http://www.woven-media.com/

A Java 6 Swing application for color testing and conversions from RGB to
hexadecimal data formats and vice versa.

Copyright (C) 2008-2009, Brent Allen Parrish <info@woven-media.com>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
************************************************************************/
package com.woven_media.colorsafe;

// woven-media.com
import com.woven_media.colorsafe.IPalette;

import java.util.ArrayList;

/**
 * NamedColors class creates a <code>java.util.ArrayList</code> of Windows-named
 * colors for direct invocation.
 *
 * @author  Brent Allen Parrish
 * @version %I%, %G%
 * @since   1.0
 */
public class NamedColors implements IPalette
{
    static ArrayList<String[]> colorList;

    /**
     * Creates a <code>java.util.ArrayList</code> of named colors.
     *
     * @return <code>java.util.ArrayList</code> of named colors mapped to hexadecimal color equivalents.
     * @see    java.util.ArrayList
     * @since  1.0
     */
    public static ArrayList<String[]> createList()
    {
        colorList =new ArrayList<String[]>();
        colorList.add(new String[] {"aliceblue",           "F0F8FF"});
        colorList.add(new String[] {"antiquewhite",        "FAEBD7"});
        colorList.add(new String[] {"aqua",                "00FFFF"});
        colorList.add(new String[] {"aquamarine",          "7FFFD4"});
        colorList.add(new String[] {"azure",               "F0FFFF"});
        colorList.add(new String[] {"beige",               "F5F5DC"});
        colorList.add(new String[] {"bisque",              "FFE4C4"});
        colorList.add(new String[] {"black",               "000000"});
        colorList.add(new String[] {"blanchedalmond",      "FFEBCD"});
        colorList.add(new String[] {"blue",                "0000FF"});
        colorList.add(new String[] {"blueviolet",          "8A2BE2"});
        colorList.add(new String[] {"brown",               "A52A2A"});
        colorList.add(new String[] {"burlywood",           "DEB887"});
        colorList.add(new String[] {"cadetblue",           "5F9EA0"});
        colorList.add(new String[] {"chartreuse",          "7FFF00"});
        colorList.add(new String[] {"chocolate",           "D2691E"});
        colorList.add(new String[] {"coral",               "FF7F50"});
        colorList.add(new String[] {"cornflowerblue",      "6495ED"});
        colorList.add(new String[] {"cornsilk",            "FFF8DC"});
        colorList.add(new String[] {"crimson",             "DC143C"});
        colorList.add(new String[] {"cyan",                "00FFFF"});
        colorList.add(new String[] {"darkblue",            "00008B"});
        colorList.add(new String[] {"darkcyan",            "008B8B"});
        colorList.add(new String[] {"darkgoldenrod",       "B8860B"});
        colorList.add(new String[] {"darkgray",            "A9A9A9"});
        colorList.add(new String[] {"darkgreen",           "006400"});
        colorList.add(new String[] {"darkkhaki",           "BDB76B"});
        colorList.add(new String[] {"darkmagenta",         "8B008B"});
        colorList.add(new String[] {"darkolivegreen",      "556B2F"});
        colorList.add(new String[] {"darkorange",          "FF8C00"});
        colorList.add(new String[] {"darkorchid",          "9932CC"});
        colorList.add(new String[] {"darkred",             "8B0000"});
        colorList.add(new String[] {"darksalmon",          "E9967A"});
        colorList.add(new String[] {"darkseagreen",        "8FBC8B"});
        colorList.add(new String[] {"darkslateblue",       "483D8B"});
        colorList.add(new String[] {"darkslategray",       "2F4F4F"});
        colorList.add(new String[] {"darkturquoise",       "00CED1"});
        colorList.add(new String[] {"darkviolet",          "9400D3"});
        colorList.add(new String[] {"deeppink",            "FF1493"});
        colorList.add(new String[] {"deepskyblue",         "00BFFF"});
        colorList.add(new String[] {"dimgray",             "696969"});
        colorList.add(new String[] {"dodgerblue",          "1E90FF"});
        colorList.add(new String[] {"firebrick",           "B22222"});
        colorList.add(new String[] {"floralwhite",         "FFFAF0"});
        colorList.add(new String[] {"forestgreen",         "228B22"});
        colorList.add(new String[] {"fuchsia",             "FF00FF"});
        colorList.add(new String[] {"gainsboro",           "DCDCDC"});
        colorList.add(new String[] {"ghostwhite",          "F8F8FF"});
        colorList.add(new String[] {"gold",                "FFD700"});
        colorList.add(new String[] {"goldenrod",           "DAA520"});
        colorList.add(new String[] {"gray",                "808080"});
        colorList.add(new String[] {"green",               "008000"});
        colorList.add(new String[] {"greenyellow",         "ADFF2F"});
        colorList.add(new String[] {"honeydew",            "F0FFF0"});
        colorList.add(new String[] {"hotpink",             "FF69B4"});
        colorList.add(new String[] {"indianred",           "CD5C5C"});
        colorList.add(new String[] {"indigo",              "4B0082"});
        colorList.add(new String[] {"ivory",               "FFFFF0"});
        colorList.add(new String[] {"khaki",               "F0E68C"});
        colorList.add(new String[] {"lavender",            "E6E6FA"});
        colorList.add(new String[] {"lavenderblush",       "FFF0F5"});
        colorList.add(new String[] {"lawngreen",           "7CFC00"});
        colorList.add(new String[] {"lemonchiffon",        "FFFACD"});
        colorList.add(new String[] {"lightblue",           "ADD8E6"});
        colorList.add(new String[] {"lightcoral",          "F08080"});
        colorList.add(new String[] {"lightcyan",           "E0FFFF"});
        colorList.add(new String[] {"lightgoldenrodyellow","FAFAD2"});
        colorList.add(new String[] {"lightgreen",          "90EE90"});
        colorList.add(new String[] {"lightgrey",           "D3D3D3"});
        colorList.add(new String[] {"lightpink",           "FFB6C1"});
        colorList.add(new String[] {"lightsalmon",         "FFA07A"});
        colorList.add(new String[] {"lightseagreen",       "20B2AA"});
        colorList.add(new String[] {"lightskyblue",        "87CEFA"});
        colorList.add(new String[] {"lightslategray",      "778899"});
        colorList.add(new String[] {"lightsteelblue",      "B0C4DE"});
        colorList.add(new String[] {"lightyellow",         "FFFFE0"});
        colorList.add(new String[] {"lime",                "00FF00"});
        colorList.add(new String[] {"limegreen",           "32CD32"});
        colorList.add(new String[] {"linen",               "FAF0E6"});
        colorList.add(new String[] {"magenta",             "FF00FF"});
        colorList.add(new String[] {"maroon",              "800000"});
        colorList.add(new String[] {"mediumaquamarine",    "66CDAA"});
        colorList.add(new String[] {"mediumblue",          "0000CD"});
        colorList.add(new String[] {"mediumorchid",        "BA55D3"});
        colorList.add(new String[] {"mediumpurple",        "9370DB"});
        colorList.add(new String[] {"mediumseagreen",      "3CB371"});
        colorList.add(new String[] {"mediumslateblue",     "7B68EE"});
        colorList.add(new String[] {"mediumspringgreen",   "00FA9A"});
        colorList.add(new String[] {"mediumturquoise",     "48D1CC"});
        colorList.add(new String[] {"mediumvioletred",     "C71585"});
        colorList.add(new String[] {"midnightblue",        "191970"});
        colorList.add(new String[] {"mintcream",           "F5FFFA"});
        colorList.add(new String[] {"mistyrose",           "FFE4E1"});
        colorList.add(new String[] {"moccasin",            "FFE4B5"});
        colorList.add(new String[] {"navajowhite",         "FFDEAD"});
        colorList.add(new String[] {"navy",                "000080"});
        colorList.add(new String[] {"oldlace",             "FDF5E6"});
        colorList.add(new String[] {"olive",               "808000"});
        colorList.add(new String[] {"olivedrab",           "6B8E23"});
        colorList.add(new String[] {"orange",              "FFA500"});
        colorList.add(new String[] {"orangered",           "FF4500"});
        colorList.add(new String[] {"orchid",              "DA70D6"});
        colorList.add(new String[] {"palegoldenrod",       "EEE8AA"});
        colorList.add(new String[] {"palegreen",           "98FB98"});
        colorList.add(new String[] {"paleturquoise",       "AFEEEE"});
        colorList.add(new String[] {"palevioletred",       "DB7093"});
        colorList.add(new String[] {"papayawhip",          "FFEFD5"});
        colorList.add(new String[] {"peachpuff",           "FFDAB9"});
        colorList.add(new String[] {"peru",                "CD853F"});
        colorList.add(new String[] {"pink",                "FFC0CB"});
        colorList.add(new String[] {"plum",                "DDA0DD"});
        colorList.add(new String[] {"powderblue",          "B0E0E6"});
        colorList.add(new String[] {"purple",              "800080"});
        colorList.add(new String[] {"red",                 "FF0000"});
        colorList.add(new String[] {"rosybrown",           "BC8F8F"});
        colorList.add(new String[] {"royalblue",           "4169E1"});
        colorList.add(new String[] {"saddlebrown",         "8B4513"});
        colorList.add(new String[] {"salmon",              "FA8072"});
        colorList.add(new String[] {"sandybrown",          "F4A460"});
        colorList.add(new String[] {"seagreen",            "2E8B57"});
        colorList.add(new String[] {"seashell",            "FFF5EE"});
        colorList.add(new String[] {"sienna",              "A0522D"});
        colorList.add(new String[] {"silver",              "C0C0C0"});
        colorList.add(new String[] {"skyblue",             "87CEEB"});
        colorList.add(new String[] {"slateblue",           "6A5ACD"});
        colorList.add(new String[] {"slategray",           "708090"});
        colorList.add(new String[] {"snow",                "FFFAFA"});
        colorList.add(new String[] {"springgreen",         "00FF7F"});
        colorList.add(new String[] {"steelblue",           "4682B4"});
        colorList.add(new String[] {"tan",                 "D2B48C"});
        colorList.add(new String[] {"teal",                "008080"});
        colorList.add(new String[] {"thistle",             "D8BFD8"});
        colorList.add(new String[] {"tomato",              "FF6347"});
        colorList.add(new String[] {"turquoise",           "40E0D0"});
        colorList.add(new String[] {"violet",              "EE82EE"});
        colorList.add(new String[] {"wheat",               "F5DEB3"});
        colorList.add(new String[] {"white",               "FFFFFF"});
        colorList.add(new String[] {"whitesmoke",          "F5F5F5"});
        colorList.add(new String[] {"yellow",              "FFFF00"});
        colorList.add(new String[] {"yellowgreen",         "9ACD32"});
        return colorList;
    } // end list

} // end class